summaryrefslogtreecommitdiffstats
path: root/src/sources/sourceprefs.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/sources/sourceprefs.cpp')
-rw-r--r--src/sources/sourceprefs.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/src/sources/sourceprefs.cpp b/src/sources/sourceprefs.cpp
index cabce8b..8639c93 100644
--- a/src/sources/sourceprefs.cpp
+++ b/src/sources/sourceprefs.cpp
@@ -11,55 +11,55 @@
#include "sourceprefs.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qcheckbox.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqlineedit.h>
+#include <tqcheckbox.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
/*
* Constructs a SourcePrefs as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-SourcePrefs::SourcePrefs( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+SourcePrefs::SourcePrefs( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "SourcePrefs" );
- SourcePrefsLayout = new QVBoxLayout( this, 0, 6, "SourcePrefsLayout");
+ SourcePrefsLayout = new TQVBoxLayout( this, 0, 6, "SourcePrefsLayout");
- descriptionLabel = new QLabel( this, "descriptionLabel" );
+ descriptionLabel = new TQLabel( this, "descriptionLabel" );
SourcePrefsLayout->addWidget( descriptionLabel );
- hBoxLayout = new QHBoxLayout( 0, 0, 6, "hBoxLayout");
+ hBoxLayout = new TQHBoxLayout( 0, 0, 6, "hBoxLayout");
- nameLabel = new QLabel( this, "nameLabel" );
+ nameLabel = new TQLabel( this, "nameLabel" );
hBoxLayout->addWidget( nameLabel );
- nameLineEdit = new QLineEdit( this, "nameLineEdit" );
+ nameLineEdit = new TQLineEdit( this, "nameLineEdit" );
hBoxLayout->addWidget( nameLineEdit );
- spacer8 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer8 = new TQSpacerItem( 20, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
hBoxLayout->addItem( spacer8 );
SourcePrefsLayout->addLayout( hBoxLayout );
- taskbarCheckBox = new QCheckBox( this, "taskbarCheckBox" );
+ taskbarCheckBox = new TQCheckBox( this, "taskbarCheckBox" );
SourcePrefsLayout->addWidget( taskbarCheckBox );
- hBoxLayout2 = new QHBoxLayout( 0, 0, 6, "hBoxLayout2");
- spacer8_2 = new QSpacerItem( 20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
+ hBoxLayout2 = new TQHBoxLayout( 0, 0, 6, "hBoxLayout2");
+ spacer8_2 = new TQSpacerItem( 20, 20, TQSizePolicy::Fixed, TQSizePolicy::Minimum );
hBoxLayout2->addItem( spacer8_2 );
- nameCheckBox = new QCheckBox( this, "nameCheckBox" );
+ nameCheckBox = new TQCheckBox( this, "nameCheckBox" );
hBoxLayout2->addWidget( nameCheckBox );
SourcePrefsLayout->addLayout( hBoxLayout2 );
- tooltipCheckBox = new QCheckBox( this, "tooltipCheckBox" );
+ tooltipCheckBox = new TQCheckBox( this, "tooltipCheckBox" );
SourcePrefsLayout->addWidget( tooltipCheckBox );
languageChange();
- resize( QSize(203, 127).expandedTo(minimumSizeHint()) );
+ resize( TQSize(203, 127).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
@@ -68,7 +68,7 @@ SourcePrefs::SourcePrefs( QWidget* parent, const char* name, WFlags fl )
*/
SourcePrefs::~SourcePrefs()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -11,55 +11,55 @@
/*
- * Constructs a SourcePrefs as a child of 'parent', with the
+ * Constructs a SourcePrefs as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/